=======
Credits
=======

Development Lead
----------------

* Christopher Bailey <cbailey@mort.is>

Contributors
------------

* Big thanks to andrew0 <andrew0@github.com> for reverse engineering the
  original SXM APIs used
